fuzzy_match_single

Function fuzzy_match_single 

pub fn fuzzy_match_single(target: &str, query: &str) -> Option<usize>
Fuzzy match a string against a query string. Returns a score that is higher for a more confident match, or None if the query does not match the target string.